@@ -10,10 +10,11 @@ class DummyEmailBackend(EmailBackend):
     """
 
     def publish_message(self, message):
-        self.update_message(message, state=EmailMessage.STATE.DEBUG)
+        self.update_message_after_sending(message, state=EmailMessage.STATE.DEBUG)
 
     def pull_message_info(self, message):
-        message.change_and_save(
+        self.update_message(
+            message,
             extra_sender_data={**message.extra_sender_data, 'info': {'debug': True}},
             info_changed_at=timezone.now(),
             update_only_changed_fields=True,
