@@ -33,6 +33,7 @@ DEFAULTS = {
     'SMS_BATCH_SIZE': 20,
     'SMS_BATCH_MAX_NUMBER_OF_SEND_ATTEMPTS': 3,
     'SMS_BATCH_MAX_SECONDS_TO_SEND': 60 * 60,
+    'SMS_RETRY_SENDING': True,
 
     # E-mail configuration
     'EMAIL_TEMPLATE_MODEL': 'pymess.EmailTemplate',
@@ -73,6 +74,7 @@ DEFAULTS = {
     'EMAIL_PULL_INFO_BATCH_SIZE': 100,
     'EMAIL_PULL_INFO_DELAY_SECONDS': 60 * 60,  # 1 hour
     'EMAIL_PULL_INFO_MAX_TIMEOUT_FROM_SENT_SECONDS': 60 * 60 * 24 * 30,  # 30 days
+    'EMAIL_RETRY_SENDING': True,
 
     # Dialer configuration
     'DIALER_TEMPLATE_MODEL': 'pymess.DialerTemplate',
@@ -100,6 +102,7 @@ DEFAULTS = {
     'DIALER_BATCH_SIZE': 20,
     'DIALER_BATCH_MAX_NUMBER_OF_SEND_ATTEMPTS': 3,
     'DIALER_BATCH_MAX_SECONDS_TO_SEND': 60 * 60,
+    'DIALER_RETRY_SENDING': True,
 
     # Push notification settings
     'PUSH_NOTIFICATION_TEMPLATE_MODEL': 'pymess.PushNotificationTemplate',
@@ -114,6 +117,7 @@ DEFAULTS = {
     'PUSH_NOTIFICATION_BATCH_SIZE': 20,
     'PUSH_NOTIFICATION_BATCH_MAX_NUMBER_OF_SEND_ATTEMPTS': 3,
     'PUSH_NOTIFICATION_BATCH_MAX_SECONDS_TO_SEND': 60 * 60,
+    'PUSH_NOTIFICATION_RETRY_SENDING': True,
 }
 
 
